@@ -25,6 +25,7 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from base64 import b32encode
 from yubikit.yubiotp import (
     SLOT,
     YubiOtpSession,
@@ -542,6 +543,13 @@ def chalresp(ctx, slot, key, totp, touch, force, generate):
                 "No secret key given. Please remove the --force flag, "
                 "set the KEY argument or set the --generate flag."
             )
+        elif generate:
+            key = os.urandom(20)
+            if totp:
+                b32key = b32encode(key).decode()
+                click.echo(f"Using a randomly generated key (Base32): {b32key}")
+            else:
+                click.echo(f"Using a randomly generated key: {key.hex()}")
         elif totp:
             while True:
                 key = click_prompt("Enter a secret key (base32)")
@@ -551,12 +559,8 @@ def chalresp(ctx, slot, key, totp, touch, force, generate):
                 except Exception as e:
                     click.echo(e)
         else:
-            if generate:
-                key = os.urandom(20)
-                click.echo(f"Using a randomly generated key: {key.hex()}")
-            else:
-                key = click_prompt("Enter a secret key")
-                key = parse_oath_key(key)
+            key = click_prompt("Enter a secret key")
+            key = parse_oath_key(key)
 
     cred_type = "TOTP" if totp else "challenge-response"
     force or click.confirm(
@@ -697,8 +701,8 @@ def hotp(ctx, slot, key, digits, counter, no_enter, force):
     "--new-access-code",
     metavar="HEX",
     required=False,
-    help="Set a new 6 byte access code for the slot. Set to empty to use a "
-    "prompt for input.",
+    help='Set a new 6 byte access code for the slot. Use "-" as a value to prompt for '
+    "input.",
 )
 @click.option(
     "--delete-access-code", is_flag=True, help="Remove access code from the slot."
@@ -742,7 +746,7 @@ def settings(
     """
     session = ctx.obj["session"]
 
-    if (new_access_code is not None) and delete_access_code:
+    if new_access_code and delete_access_code:
         ctx.fail("--new-access-code conflicts with --delete-access-code.")
 
     if not session.get_config_state().is_configured(slot):
@@ -752,7 +756,7 @@ def settings(
         if not delete_access_code:
             new_access_code = ctx.obj["access_code"]
     else:
-        if new_access_code == "":
+        if new_access_code == "-":
             new_access_code = click_prompt("Enter new access code", show_default=False)
 
         try:
